AnySqlCapabilityProvider class abstract interface

Implemented by drivers that explicitly describe optional functionality.

Implementers

Properties

capabilities AnySqlCapabilities
Optional functionality supported by this driver.
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited