AnySqlDialect enum

Known database families supported by the AnySQL abstraction.

Inheritance
Available extensions

Values

postgres → const AnySqlDialect

PostgreSQL-compatible relational database.

mysql → const AnySqlDialect

MySQL-compatible relational database.

sqlite → const AnySqlDialect

SQLite-compatible local relational database.

mongodb → const AnySqlDialect

MongoDB-compatible document database.

custom → const AnySqlDialect

Driver-specific database family.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<AnySqlDialect>
A constant List of the values in this enum, in order of their declaration.