PostgresAnySqlDriver class final
Real PostgreSQL driver backed by package:postgres.
This driver uses AnySqlConfig.host, AnySqlConfig.port, AnySqlConfig.database, AnySqlConfig.username, AnySqlConfig.password, and AnySqlConfig.sslEnabled to open a PostgreSQL connection.
- Inheritance
-
- Object
- AnySqlDriverBase
- PostgresAnySqlDriver
Constructors
- PostgresAnySqlDriver()
-
Creates a PostgreSQL driver.
const
Properties
- dialect → AnySqlDialect
-
Database dialect this driver supports by default.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
Human-readable driver name, such as
postgresormysql.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
checkSupported(
AnySqlConfig config) → void -
Throws when
configis not intended for this driver.inherited -
connect(
AnySqlConfig config) → Future< AnySqlConnection> -
Opens a new database connection.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
supports(
AnySqlConfig config) → bool -
Whether this driver can open a connection for
config.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited