A transaction scoped to one AnySqlConnection.
- Implemented types
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
commit(
) → Future< void> - Commits this transaction.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
query(
String statement, {Map< String, Object?> parameters = const {}}) → Future<AnySqlResult> -
Runs a statement or command within this transaction.
override
-
rollback(
) → Future< void> - Rolls this transaction back.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited