PostgresAnySqlDriver class final

Real PostgreSQL driver backed by package:postgres.

This driver uses AnySqlConfig.host, AnySqlConfig.port, AnySqlConfig.database, AnySqlConfig.username, AnySqlConfig.password, and AnySqlConfig.sslEnabled to open a PostgreSQL connection.

Inheritance
Available extensions

Constructors

PostgresAnySqlDriver()
Creates a PostgreSQL driver.
const

Properties

capabilities AnySqlCapabilities
Optional functionality supported by this driver.
finalinherited
capabilities AnySqlCapabilities

Available on AnySqlDriver, provided by the AnySqlDriverCapabilities extension

Returns declared capabilities, or a conservative empty set for legacy drivers that do not implement AnySqlCapabilityProvider.
no setter
dialect AnySqlDialect
Database dialect this driver supports by default.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
name String
Human-readable driver name, such as postgres or mysql.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

checkSupported(AnySqlConfig config) → void
Throws when config is not intended for this driver.
inherited
connect(AnySqlConfig config) Future<AnySqlConnection>
Opens a new database connection.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
supports(AnySqlConfig config) bool
Whether this driver can open a connection for config.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited